"""
Module: 'ure' on micropython-v1.19.1-esp32
"""
# MCU: {'ver': 'v1.19.1', 'build': '', 'platform': 'esp32', 'port': 'esp32', 'machine': 'ESP32S3 module with ESP32S3', 'release': '1.19.1', 'nodename': 'esp32', 'name': 'micropython', 'family': 'micropython', 'sysname': 'esp32', 'version': '1.19.1'}
# Stubber: 1.11.2
from typing import Any


def sub(*args, **kwargs) -> Any:
    ...


def search(*args, **kwargs) -> Any:
    ...


def match(*args, **kwargs) -> Any:
    ...


def compile(*args, **kwargs) -> Any:
    ...
